Functions
- apply_
along_ axis - Apply a function along one axis of an array.
- apply_
over_ axes - Apply a reducing function repeatedly over multiple axes.
- piecewise
- Evaluate a piecewise-defined function.
- sum_
axis_ keepdims - Helper: sum along an axis with keepdims semantics (keeps the axis as size 1).
- vectorize
- Wrap a scalar function to operate elementwise on arrays.
- vectorize_
nd - Wrap a scalar function to operate elementwise on arrays of any dimension.