kaiser

Function kaiser 

pub fn kaiser(m: usize, beta: f64) -> FerrayResult<Array<f64, Ix1>>
Return the Kaiser window of length m with shape parameter beta.

The Kaiser window is defined as: w(n) = I_0(beta * sqrt(1 - ((2n/(M-1)) - 1)^2)) / I_0(beta)

where I_0 is the modified Bessel function of the first kind, order 0.

This is equivalent to numpy.kaiser(M, beta).

Edge Cases

  • m == 0: returns an empty array.
  • m == 1: returns [1.0].

Errors

Returns FerrayError::InvalidValue if beta is NaN.